==> zio-aws-firehose_2.13-7.28.26.1-sources.jar: zio/aws/firehose/model/ExtendedS3DestinationConfiguration.scala <==
package zio.aws.firehose.model
import zio.aws.firehose.model.primitives.{
  CustomTimeZone,
  ErrorOutputPrefix,
  BucketARN,
  Prefix,
  FileExtension,
  RoleARN
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ExtendedS3DestinationConfiguration(
    roleARN: RoleARN,
    bucketARN: BucketARN,
    prefix: Optional[Prefix] = Optional.Absent,
    errorOutputPrefix: Optional[ErrorOutputPrefix] = Optional.Absent,
    bufferingHints: Optional[zio.aws.firehose.model.BufferingHints] =
      Optional.Absent,
    compressionFormat: Optional[zio.aws.firehose.model.CompressionFormat] =
      Optional.Absent,
    encryptionConfiguration: Optional[
      zio.aws.firehose.model.EncryptionConfiguration
    ] = Optional.Absent,
    cloudWatchLoggingOptions: Optional[
      zio.aws.firehose.model.CloudWatchLoggingOptions
    ] = Optional.Absent,
    processingConfiguration: Optional[
      zio.aws.firehose.model.ProcessingConfiguration
    ] = Optional.Absent,
    s3BackupMode: Optional[zio.aws.firehose.model.S3BackupMode] =
      Optional.Absent,
    s3BackupConfiguration: Optional[
      zio.aws.firehose.model.S3DestinationConfiguration
    ] = Optional.Absent,
    dataFormatConversionConfiguration: Optional[
      zio.aws.firehose.model.DataFormatConversionConfiguration
    ] = Optional.Absent,
    dynamicPartitioningConfiguration: Optional[
      zio.aws.firehose.model.DynamicPartitioningConfiguration
    ] = Optional.Absent,
    fileExtension: Optional[FileExtension] = Optional.Absent,
    customTimeZone: Optional[CustomTimeZone] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.firehose.model.ExtendedS3DestinationConfiguration = {
    import ExtendedS3DestinationConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.firehose.model.ExtendedS3DestinationConfiguration
      .builder()
      .roleARN(RoleARN.unwrap(roleARN): java.lang.String)
      .bucketARN(BucketARN.unwrap(bucketARN): java.lang.String)
      .optionallyWith(
        prefix.map(value => Prefix.unwrap(value): java.lang.String)
      )(_.prefix)
      .optionallyWith(
        errorOutputPrefix.map(value =>
          ErrorOutputPrefix.unwrap(value): java.lang.String
        )
      )(_.errorOutputPrefix)
      .optionallyWith(bufferingHints.map(value => value.buildAwsValue()))(
        _.bufferingHints
      )
      .optionallyWith(compressionFormat.map(value => value.unwrap))(
        _.compressionFormat
      )
      .optionallyWith(
        encryptionConfiguration.map(value => value.buildAwsValue())
      )(_.encryptionConfiguration)
      .optionallyWith(
        cloudWatchLoggingOptions.map(value => value.buildAwsValue())
      )(_.cloudWatchLoggingOptions)
      .optionallyWith(
        processingConfiguration.map(value => value.buildAwsValue())
      )(_.processingConfiguration)
      .optionallyWith(s3BackupMode.map(value => value.unwrap))(_.s3BackupMode)
      .optionallyWith(
        s3BackupConfiguration.map(value => value.buildAwsValue())
      )(_.s3BackupConfiguration)
      .optionallyWith(
        dataFormatConversionConfiguration.map(value => value.buildAwsValue())
      )(_.dataFormatConversionConfiguration)
      .optionallyWith(
        dynamicPartitioningConfiguration.map(value => value.buildAwsValue())
      )(_.dynamicPartitioningConfiguration)
      .optionallyWith(
        fileExtension.map(value =>
          FileExtension.unwrap(value): java.lang.String
        )
      )(_.fileExtension)
      .optionallyWith(
        customTimeZone.map(value =>
          CustomTimeZone.unwrap(value): java.lang.String
        )
      )(_.customTimeZone)
      .build()
  }
  def asReadOnly
      : zio.aws.firehose.model.ExtendedS3DestinationConfiguration.ReadOnly =
    zio.aws.firehose.model.ExtendedS3DestinationConfiguration
      .wrap(buildAwsValue())
}
object ExtendedS3DestinationConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.firehose.model.ExtendedS3DestinationConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.firehose.model.ExtendedS3DestinationConfiguration =
      zio.aws.firehose.model.ExtendedS3DestinationConfiguration(
        roleARN,
        bucketARN,
        prefix.map(value => value),
        errorOutputPrefix.map(value => value),
        bufferingHints.map(value => value.asEditable),
        compressionFormat.map(value => value),
        encryptionConfiguration.map(value => value.asEditable),
        cloudWatchLoggingOptions.map(value => value.asEditable),
        processingConfiguration.map(value => value.asEditable),
        s3BackupMode.map(value => value),
        s3BackupConfiguration.map(value => value.asEditable),
        dataFormatConversionConfiguration.map(value => value.asEditable),
        dynamicPartitioningConfiguration.map(value => value.asEditable),
        fileExtension.map(value => value),
        customTimeZone.map(value => value)
      )
    def roleARN: RoleARN
    def bucketARN: BucketARN
    def prefix: Optional[Prefix]
    def errorOutputPrefix: Optional[ErrorOutputPrefix]
    def bufferingHints: Optional[zio.aws.firehose.model.BufferingHints.ReadOnly]
    def compressionFormat: Optional[zio.aws.firehose.model.CompressionFormat]
    def encryptionConfiguration
        : Optional[zio.aws.firehose.model.EncryptionConfiguration.ReadOnly]
    def cloudWatchLoggingOptions
        : Optional[zio.aws.firehose.model.CloudWatchLoggingOptions.ReadOnly]
    def processingConfiguration
        : Optional[zio.aws.firehose.model.ProcessingConfiguration.ReadOnly]
    def s3BackupMode: Optional[zio.aws.firehose.model.S3BackupMode]
    def s3BackupConfiguration
        : Optional[zio.aws.firehose.model.S3DestinationConfiguration.ReadOnly]
    def dataFormatConversionConfiguration: Optional[
      zio.aws.firehose.model.DataFormatConversionConfiguration.ReadOnly
    ]
    def dynamicPartitioningConfiguration: Optional[
      zio.aws.firehose.model.DynamicPartitioningConfiguration.ReadOnly
    ]
    def fileExtension: Optional[FileExtension]
    def customTimeZone: Optional[CustomTimeZone]
    def getRoleARN: ZIO[Any, Nothing, RoleARN] = ZIO.succeed(roleARN)
    def getBucketARN: ZIO[Any, Nothing, BucketARN] = ZIO.succeed(bucketARN)
    def getPrefix: ZIO[Any, AwsError, Prefix] =
      AwsError.unwrapOptionField("prefix", prefix)
    def getErrorOutputPrefix: ZIO[Any, AwsError, ErrorOutputPrefix] =
      AwsError.unwrapOptionField("errorOutputPrefix", errorOutputPrefix)
    def getBufferingHints
        : ZIO[Any, AwsError, zio.aws.firehose.model.BufferingHints.ReadOnly] =
      AwsError.unwrapOptionField("bufferingHints", bufferingHints)
    def getCompressionFormat
        : ZIO[Any, AwsError, zio.aws.firehose.model.CompressionFormat] =
      AwsError.unwrapOptionField("compressionFormat", compressionFormat)
    def getEncryptionConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.EncryptionConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "encryptionConfiguration",
      encryptionConfiguration
    )
    def getCloudWatchLoggingOptions: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.CloudWatchLoggingOptions.ReadOnly
    ] = AwsError.unwrapOptionField(
      "cloudWatchLoggingOptions",
      cloudWatchLoggingOptions
    )
    def getProcessingConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.ProcessingConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "processingConfiguration",
      processingConfiguration
    )
    def getS3BackupMode
        : ZIO[Any, AwsError, zio.aws.firehose.model.S3BackupMode] =
      AwsError.unwrapOptionField("s3BackupMode", s3BackupMode)
    def getS3BackupConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.S3DestinationConfiguration.ReadOnly
    ] =
      AwsError.unwrapOptionField("s3BackupConfiguration", s3BackupConfiguration)
    def getDataFormatConversionConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.DataFormatConversionConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "dataFormatConversionConfiguration",
      dataFormatConversionConfiguration
    )
    def getDynamicPartitioningConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.DynamicPartitioningConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "dynamicPartitioningConfiguration",
      dynamicPartitioningConfiguration
    )
    def getFileExtension: ZIO[Any, AwsError, FileExtension] =
      AwsError.unwrapOptionField("fileExtension", fileExtension)
    def getCustomTimeZone: ZIO[Any, AwsError, CustomTimeZone] =
      AwsError.unwrapOptionField("customTimeZone", customTimeZone)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.firehose.model.ExtendedS3DestinationConfiguration
  ) extends zio.aws.firehose.model.ExtendedS3DestinationConfiguration.ReadOnly {
    override val roleARN: RoleARN =
      zio.aws.firehose.model.primitives.RoleARN(impl.roleARN())
    override val bucketARN: BucketARN =
      zio.aws.firehose.model.primitives.BucketARN(impl.bucketARN())
    override val prefix: Optional[Prefix] = zio.aws.core.internal
      .optionalFromNullable(impl.prefix())
      .map(value => zio.aws.firehose.model.primitives.Prefix(value))
    override val errorOutputPrefix: Optional[ErrorOutputPrefix] =
      zio.aws.core.internal
        .optionalFromNullable(impl.errorOutputPrefix())
        .map(value =>
          zio.aws.firehose.model.primitives.ErrorOutputPrefix(value)
        )
    override val bufferingHints
        : Optional[zio.aws.firehose.model.BufferingHints.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.bufferingHints())
        .map(value => zio.aws.firehose.model.BufferingHints.wrap(value))
    override val compressionFormat
        : Optional[zio.aws.firehose.model.CompressionFormat] =
      zio.aws.core.internal
        .optionalFromNullable(impl.compressionFormat())
        .map(value => zio.aws.firehose.model.CompressionFormat.wrap(value))
    override val encryptionConfiguration
        : Optional[zio.aws.firehose.model.EncryptionConfiguration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.encryptionConfiguration())
        .map(value =>
          zio.aws.firehose.model.EncryptionConfiguration.wrap(value)
        )
    override val cloudWatchLoggingOptions
        : Optional[zio.aws.firehose.model.CloudWatchLoggingOptions.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.cloudWatchLoggingOptions())
        .map(value =>
          zio.aws.firehose.model.CloudWatchLoggingOptions.wrap(value)
        )
    override val processingConfiguration
        : Optional[zio.aws.firehose.model.ProcessingConfiguration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.processingConfiguration())
        .map(value =>
          zio.aws.firehose.model.ProcessingConfiguration.wrap(value)
        )
    override val s3BackupMode: Optional[zio.aws.firehose.model.S3BackupMode] =
      zio.aws.core.internal
        .optionalFromNullable(impl.s3BackupMode())
        .map(value => zio.aws.firehose.model.S3BackupMode.wrap(value))
    override val s3BackupConfiguration
        : Optional[zio.aws.firehose.model.S3DestinationConfiguration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.s3BackupConfiguration())
        .map(value =>
          zio.aws.firehose.model.S3DestinationConfiguration.wrap(value)
        )
    override val dataFormatConversionConfiguration: Optional[
      zio.aws.firehose.model.DataFormatConversionConfiguration.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.dataFormatConversionConfiguration())
      .map(value =>
        zio.aws.firehose.model.DataFormatConversionConfiguration.wrap(value)
      )
    override val dynamicPartitioningConfiguration: Optional[
      zio.aws.firehose.model.DynamicPartitioningConfiguration.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.dynamicPartitioningConfiguration())
      .map(value =>
        zio.aws.firehose.model.DynamicPartitioningConfiguration.wrap(value)
      )
    override val fileExtension: Optional[FileExtension] = zio.aws.core.internal
      .optionalFromNullable(impl.fileExtension())
      .map(value => zio.aws.firehose.model.primitives.FileExtension(value))
    override val customTimeZone: Optional[CustomTimeZone] =
      zio.aws.core.internal
        .optionalFromNullable(impl.customTimeZone())
        .map(value => zio.aws.firehose.model.primitives.CustomTimeZone(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.firehose.model.ExtendedS3DestinationConfiguration
  ): zio.aws.firehose.model.ExtendedS3DestinationConfiguration.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-firehose_3-5.17.104.5-sources.jar: zio/aws/firehose/model/ExtendedS3DestinationConfiguration.scala <==
package zio.aws.firehose.model
import zio.aws.firehose.model.primitives.{
  ErrorOutputPrefix,
  Prefix,
  BucketARN,
  RoleARN
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ExtendedS3DestinationConfiguration(
    roleARN: RoleARN,
    bucketARN: BucketARN,
    prefix: Option[Prefix] = None,
    errorOutputPrefix: Option[ErrorOutputPrefix] = None,
    bufferingHints: Option[zio.aws.firehose.model.BufferingHints] = None,
    compressionFormat: Option[zio.aws.firehose.model.CompressionFormat] = None,
    encryptionConfiguration: Option[
      zio.aws.firehose.model.EncryptionConfiguration
    ] = None,
    cloudWatchLoggingOptions: Option[
      zio.aws.firehose.model.CloudWatchLoggingOptions
    ] = None,
    processingConfiguration: Option[
      zio.aws.firehose.model.ProcessingConfiguration
    ] = None,
    s3BackupMode: Option[zio.aws.firehose.model.S3BackupMode] = None,
    s3BackupConfiguration: Option[
      zio.aws.firehose.model.S3DestinationConfiguration
    ] = None,
    dataFormatConversionConfiguration: Option[
      zio.aws.firehose.model.DataFormatConversionConfiguration
    ] = None,
    dynamicPartitioningConfiguration: Option[
      zio.aws.firehose.model.DynamicPartitioningConfiguration
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.firehose.model.ExtendedS3DestinationConfiguration = {
    import ExtendedS3DestinationConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.firehose.model.ExtendedS3DestinationConfiguration
      .builder()
      .roleARN(RoleARN.unwrap(roleARN): java.lang.String)
      .bucketARN(BucketARN.unwrap(bucketARN): java.lang.String)
      .optionallyWith(
        prefix.map(value => Prefix.unwrap(value): java.lang.String)
      )(_.prefix)
      .optionallyWith(
        errorOutputPrefix.map(value =>
          ErrorOutputPrefix.unwrap(value): java.lang.String
        )
      )(_.errorOutputPrefix)
      .optionallyWith(bufferingHints.map(value => value.buildAwsValue()))(
        _.bufferingHints
      )
      .optionallyWith(compressionFormat.map(value => value.unwrap))(
        _.compressionFormat
      )
      .optionallyWith(
        encryptionConfiguration.map(value => value.buildAwsValue())
      )(_.encryptionConfiguration)
      .optionallyWith(
        cloudWatchLoggingOptions.map(value => value.buildAwsValue())
      )(_.cloudWatchLoggingOptions)
      .optionallyWith(
        processingConfiguration.map(value => value.buildAwsValue())
      )(_.processingConfiguration)
      .optionallyWith(s3BackupMode.map(value => value.unwrap))(_.s3BackupMode)
      .optionallyWith(
        s3BackupConfiguration.map(value => value.buildAwsValue())
      )(_.s3BackupConfiguration)
      .optionallyWith(
        dataFormatConversionConfiguration.map(value => value.buildAwsValue())
      )(_.dataFormatConversionConfiguration)
      .optionallyWith(
        dynamicPartitioningConfiguration.map(value => value.buildAwsValue())
      )(_.dynamicPartitioningConfiguration)
      .build()
  }
  def asReadOnly
      : zio.aws.firehose.model.ExtendedS3DestinationConfiguration.ReadOnly =
    zio.aws.firehose.model.ExtendedS3DestinationConfiguration
      .wrap(buildAwsValue())
}
object ExtendedS3DestinationConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.firehose.model.ExtendedS3DestinationConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.firehose.model.ExtendedS3DestinationConfiguration =
      zio.aws.firehose.model.ExtendedS3DestinationConfiguration(
        roleARN,
        bucketARN,
        prefix.map(value => value),
        errorOutputPrefix.map(value => value),
        bufferingHints.map(value => value.asEditable),
        compressionFormat.map(value => value),
        encryptionConfiguration.map(value => value.asEditable),
        cloudWatchLoggingOptions.map(value => value.asEditable),
        processingConfiguration.map(value => value.asEditable),
        s3BackupMode.map(value => value),
        s3BackupConfiguration.map(value => value.asEditable),
        dataFormatConversionConfiguration.map(value => value.asEditable),
        dynamicPartitioningConfiguration.map(value => value.asEditable)
      )
    def roleARN: RoleARN
    def bucketARN: BucketARN
    def prefix: Option[Prefix]
    def errorOutputPrefix: Option[ErrorOutputPrefix]
    def bufferingHints: Option[zio.aws.firehose.model.BufferingHints.ReadOnly]
    def compressionFormat: Option[zio.aws.firehose.model.CompressionFormat]
    def encryptionConfiguration
        : Option[zio.aws.firehose.model.EncryptionConfiguration.ReadOnly]
    def cloudWatchLoggingOptions
        : Option[zio.aws.firehose.model.CloudWatchLoggingOptions.ReadOnly]
    def processingConfiguration
        : Option[zio.aws.firehose.model.ProcessingConfiguration.ReadOnly]
    def s3BackupMode: Option[zio.aws.firehose.model.S3BackupMode]
    def s3BackupConfiguration
        : Option[zio.aws.firehose.model.S3DestinationConfiguration.ReadOnly]
    def dataFormatConversionConfiguration: Option[
      zio.aws.firehose.model.DataFormatConversionConfiguration.ReadOnly
    ]
    def dynamicPartitioningConfiguration: Option[
      zio.aws.firehose.model.DynamicPartitioningConfiguration.ReadOnly
    ]
    def getRoleARN: ZIO[Any, Nothing, RoleARN] = ZIO.succeed(roleARN)
    def getBucketARN: ZIO[Any, Nothing, BucketARN] = ZIO.succeed(bucketARN)
    def getPrefix: ZIO[Any, AwsError, Prefix] =
      AwsError.unwrapOptionField("prefix", prefix)
    def getErrorOutputPrefix: ZIO[Any, AwsError, ErrorOutputPrefix] =
      AwsError.unwrapOptionField("errorOutputPrefix", errorOutputPrefix)
    def getBufferingHints
        : ZIO[Any, AwsError, zio.aws.firehose.model.BufferingHints.ReadOnly] =
      AwsError.unwrapOptionField("bufferingHints", bufferingHints)
    def getCompressionFormat
        : ZIO[Any, AwsError, zio.aws.firehose.model.CompressionFormat] =
      AwsError.unwrapOptionField("compressionFormat", compressionFormat)
    def getEncryptionConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.EncryptionConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "encryptionConfiguration",
      encryptionConfiguration
    )
    def getCloudWatchLoggingOptions: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.CloudWatchLoggingOptions.ReadOnly
    ] = AwsError.unwrapOptionField(
      "cloudWatchLoggingOptions",
      cloudWatchLoggingOptions
    )
    def getProcessingConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.ProcessingConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "processingConfiguration",
      processingConfiguration
    )
    def getS3BackupMode
        : ZIO[Any, AwsError, zio.aws.firehose.model.S3BackupMode] =
      AwsError.unwrapOptionField("s3BackupMode", s3BackupMode)
    def getS3BackupConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.S3DestinationConfiguration.ReadOnly
    ] =
      AwsError.unwrapOptionField("s3BackupConfiguration", s3BackupConfiguration)
    def getDataFormatConversionConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.DataFormatConversionConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "dataFormatConversionConfiguration",
      dataFormatConversionConfiguration
    )
    def getDynamicPartitioningConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.DynamicPartitioningConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "dynamicPartitioningConfiguration",
      dynamicPartitioningConfiguration
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.firehose.model.ExtendedS3DestinationConfiguration
  ) extends zio.aws.firehose.model.ExtendedS3DestinationConfiguration.ReadOnly {
    override val roleARN: RoleARN =
      zio.aws.firehose.model.primitives.RoleARN(impl.roleARN())
    override val bucketARN: BucketARN =
      zio.aws.firehose.model.primitives.BucketARN(impl.bucketARN())
    override val prefix: Option[Prefix] = scala
      .Option(impl.prefix())
      .map(value => zio.aws.firehose.model.primitives.Prefix(value))
    override val errorOutputPrefix: Option[ErrorOutputPrefix] = scala
      .Option(impl.errorOutputPrefix())
      .map(value => zio.aws.firehose.model.primitives.ErrorOutputPrefix(value))
    override val bufferingHints
        : Option[zio.aws.firehose.model.BufferingHints.ReadOnly] = scala
      .Option(impl.bufferingHints())
      .map(value => zio.aws.firehose.model.BufferingHints.wrap(value))
    override val compressionFormat
        : Option[zio.aws.firehose.model.CompressionFormat] = scala
      .Option(impl.compressionFormat())
      .map(value => zio.aws.firehose.model.CompressionFormat.wrap(value))
    override val encryptionConfiguration
        : Option[zio.aws.firehose.model.EncryptionConfiguration.ReadOnly] =
      scala
        .Option(impl.encryptionConfiguration())
        .map(value =>
          zio.aws.firehose.model.EncryptionConfiguration.wrap(value)
        )
    override val cloudWatchLoggingOptions
        : Option[zio.aws.firehose.model.CloudWatchLoggingOptions.ReadOnly] =
      scala
        .Option(impl.cloudWatchLoggingOptions())
        .map(value =>
          zio.aws.firehose.model.CloudWatchLoggingOptions.wrap(value)
        )
    override val processingConfiguration
        : Option[zio.aws.firehose.model.ProcessingConfiguration.ReadOnly] =
      scala
        .Option(impl.processingConfiguration())
        .map(value =>
          zio.aws.firehose.model.ProcessingConfiguration.wrap(value)
        )
    override val s3BackupMode: Option[zio.aws.firehose.model.S3BackupMode] =
      scala
        .Option(impl.s3BackupMode())
        .map(value => zio.aws.firehose.model.S3BackupMode.wrap(value))
    override val s3BackupConfiguration
        : Option[zio.aws.firehose.model.S3DestinationConfiguration.ReadOnly] =
      scala
        .Option(impl.s3BackupConfiguration())
        .map(value =>
          zio.aws.firehose.model.S3DestinationConfiguration.wrap(value)
        )
    override val dataFormatConversionConfiguration: Option[
      zio.aws.firehose.model.DataFormatConversionConfiguration.ReadOnly
    ] = scala
      .Option(impl.dataFormatConversionConfiguration())
      .map(value =>
        zio.aws.firehose.model.DataFormatConversionConfiguration.wrap(value)
      )
    override val dynamicPartitioningConfiguration: Option[
      zio.aws.firehose.model.DynamicPartitioningConfiguration.ReadOnly
    ] = scala
      .Option(impl.dynamicPartitioningConfiguration())
      .map(value =>
        zio.aws.firehose.model.DynamicPartitioningConfiguration.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.firehose.model.ExtendedS3DestinationConfiguration
  ): zio.aws.firehose.model.ExtendedS3DestinationConfiguration.ReadOnly =
    new Wrapper(impl)
}
